Welcome to AstroCabTools — AstroCabTools 0.9.11 documentation

# Welcome to AstroCabTools

Set of tools that analize data from JWST in Python

Current version is 0.9.11

# Acknowledgment

This work has been partially funded by the Ministerio de Ciencia e Innovación through its program “promoción de empleo joven e implantación de la Garantía Juvenil en I+D+i 2018, PEJ2018-002877-A”, the Comunidad de Madrid through the Atracción de Talento grant 2017-T1/TIC-5213, and he Spanish State Research Agency (AEI) Project MDM-2017-0737 Unidad de Excelencia “María de Maeztu”- Centro de Astrobiología (CSIC-INTA).

# Key Features

- Integrate processing tools, algorithms, visualizationd and data analyisis of images and 3D infrarred spectroscopy for the James Webb Espacial Telescope (JWST).

- Integration of JWST calibrated data and advance products into astronomic data bases and astrophisics specialized packages.

- Developing of procedures to the JWST data combination and the joint analyisis of large volumes of data.

- Simulation and study of observations made from the MIRI tool of the JWST with the MIRISim simulator.

# Libraries Used

- PyQt - Binding of C++ GUI library.

- Numpy - Library that allow large data manipulation in python.

- Matplotlib - Grpah visualization library.

- Astropy - Collection of software packages used for astronomy.

- Seaborn - Statistical data visualization.

- Lmfit - Non-Linear Least-Squares Minimization and Curve-Fitting for python.

- PyPubSub - Package that provides a publish-subscrive API.

- Photutils - Package that provides tools for detecting and performing photometry of astronomical sources.

# Tools Installation

The set of tools can be downloaded using the next pip command:

    $ pip install AstroCabTools

# Tools execution

all_tools execution:

    $ allTools

mrs_chan execution:

    $ bandChan

mrs_spec_chan execution:

    $ specChan

mrs_det_plot execution:

    $ detPlot

fit_line execution:

    $ fitLine

# Beta Versions

Currently mrs_chan, mrs_spec_chan and mrs_det_plot are tools in beta versions.

# Tutorials

1. Mrs_chan tutorial

2. Mrs_spec_chan tutorial

3. Mrs_det_plot tutorial

4. Fit Line Tutorial

5. All_tools Tutorial

# Authors

The `AstroCabTools` package has been developed by the INTA Research and Development Group as part of the JWST/MIRI consortium. The main contributors to this software are:

Alejandro Gorgues Valenciano. Centro de Astrobiología (CSIC-INTA), Madrid, Spain

# Table of Contents

- Mrs_chan tutorial
  - Overview
  - Requirements
  - Data insertion
  - Results
  - Examples
- Mrs_spec_chan tutorial
  - Overview
  - Requirements
  - Data insertion
  - Examples
- Mrs_det_plot tutorial
  - Overview
  - Requirements
  - Initial display
  - Data insertion
  - Image manipulation
  - Examples
- Fit Line Tutorial
  - Overview
  - Requirements
  - Initial display
  - Data insertion
  - Spectrum interaction
  - Gauss fitted model creation
  - Gauss fitted model results
  - Erase options
  - Gauss fitted model data
  - Show residuals
  - Save figure image
  - Examples
- All_tools Tutorial
  - Overview
  - Requirements
  - Main window display
- Templates
  - Overview
  - Mrs_spec_chan templates
  - Mrs_det_plot templates
  - Fit_line templates